@@ -534,7 +534,7 @@ runexttosim:
 
     if (err_result == TRUE)
     {
-	EFDone();
+	EFDone(NULL);
         return /* TCL_ERROR */;
     }
 
@@ -548,7 +548,7 @@ runexttosim:
 	if (w == (MagWindow *) NULL)
 	{
 	    TxError("Point to a window or specify a cell name.\n");
-	    EFDone();
+	    EFDone(NULL);
 	    return /* TCL_ERROR */;
 	}
 	inName = ((CellUse *) w->w_surfaceID)->cu_def->cd_name;
@@ -585,7 +585,7 @@ runexttosim:
 #else
 	TxError("exttosim: Unable to open file %s for writing\n", simesOutName);
 #endif
-	EFDone();
+	EFDone(NULL);
 	return /* TCL_ERROR */;
     }
     if (!esNoAlias && (esAliasF = fopen(esAliasName, "w")) == NULL)
@@ -598,7 +598,7 @@ runexttosim:
 #else
 	TxError("exttosim: Unable to open file %s for writing\n", esAliasName);
 #endif
-	EFDone();
+	EFDone(NULL);
 	return /* TCL_ERROR */;
     }
     if (!esNoLabel && (esLabF = fopen(esLabelName, "w")) == NULL)
@@ -617,7 +617,7 @@ runexttosim:
     /* Read the hierarchical description of the input circuit */
     if (EFReadFile(inName, FALSE, esDoSimExtResis, FALSE, FALSE) == FALSE)
     {
-	EFDone();
+	EFDone(NULL);
 	return /* TCL_ERROR */;
     }
 
