@@ -2,16 +2,16 @@
  *
  * The greedy router, debug routines.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
@@ -20,6 +20,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdint.h>
 #include <sys/types.h>
 #include <sys/times.h>
 
@@ -48,7 +49,7 @@ bool gcrMakeChannel();
 void gcrPrintCol(GCRChannel *, int, int);
 
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -106,13 +107,13 @@ GCRRouteFromFile(fname)
     (void) GCRroute(ch);
     times(&tbuf2);
     TxPrintf("Time   :  %5.2fu  %5.2fs\n", (tbuf2.tms_utime -
-	    tbuf1.tms_utime)/60.0, (tbuf2.tms_stime-tbuf1.tms_stime)*60);
+	    tbuf1.tms_utime)/60.0, (double)(tbuf2.tms_stime-tbuf1.tms_stime)*60);
 
     gcrDumpResult(ch, GcrShowEnd);
     gcrShowMap(ch);
     return (ch);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -194,7 +195,7 @@ gcrMakeChannel(ch, fp)
 	     * p and P mean poly is blocked.  Upper case means vacate the
 	     * column, lower case means vacate the track.
 	     */
-	    if (fscanf(fp, "%s", s) != 1)
+	    if (fscanf(fp, "%24s", s) != 1)
 	    {
 		TxError("Format error in router input file\n");
 		return (FALSE);
@@ -251,14 +252,17 @@ gcrMakePinLR(fp, x, size)
     result[size + 1].gcr_pId = (GCRNet *) NULL;
     for (i = 1; i <= size; i++)
     {
-	(void) fscanf(fp, "%d", &result[i].gcr_pId);
+	/* FIXME: Reading a pointer from file is almost guaranteed to break. */
+	dlong pointer_bits;
+	(void) fscanf(fp, "%"DLONG_PREFIX"d", &pointer_bits);
+	result[i].gcr_pId = (struct gcrnet *) pointer_bits;
 	result[i].gcr_x = x;
 	result[i].gcr_y = i;
     }
 
     return (result);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -284,7 +288,7 @@ gcrSaveChannel(ch)
     char name[128];
     int flags, i, j;
 
-    (void) sprintf(name, "chan.%x", ch);
+    (void) sprintf(name, "chan.%p", ch);
     fp = fopen(name, "w");
     if (fp == NULL)
     {
@@ -340,7 +344,7 @@ gcrSaveChannel(ch)
     fprintf(fp, "\n");
     (void) fclose(fp);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -369,14 +373,13 @@ gcrPrDensity(ch, chanDensity)
 {
     int i, diff;
     char name[256];
-    FILE *fp;
+    FILE *fp, *fp_always_close;
 
     (void) sprintf(name, "dens.%d.%d.%d.%d",
 		ch->gcr_area.r_xbot, ch->gcr_area.r_ybot,
 		ch->gcr_area.r_xtop, ch->gcr_area.r_ytop);
-    fp = fopen(name, "w");
-    if (fp == NULL)
-	fp = stdout;
+    fp_always_close = fopen(name, "w");
+    fp = fp_always_close ? fp_always_close : stdout;
 
     fprintf(fp, "Chan width: %d\n", ch->gcr_width);
     fprintf(fp, "Chan length: %d\n", ch->gcr_length);
@@ -420,10 +423,10 @@ gcrPrDensity(ch, chanDensity)
     }
 
     (void) fflush(fp);
-    if (fp != stdout)
-	(void) fclose(fp);
+    if (fp_always_close != NULL)
+	(void) fclose(fp_always_close);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -451,36 +454,36 @@ gcrDumpPins(ch)
     TxPrintf("LEFT PINS\n");
     for(i=0; i<=ch->gcr_width; i++)
     {
-	TxPrintf("Location [%d]=%d:  x=%d, y=%d, pNext=%d, pPrev=%d, id=%d\n",
-	i, &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
-	pinArray[i].gcr_pNext, pinArray[i].gcr_pPrev, pinArray[i].gcr_pId);
+	TxPrintf("Location [%d]=%ld:  x=%d, y=%d, pNext=%ld, pPrev=%ld, id=%ld\n",
+	i, (intmax_t) &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
+	(intmax_t) pinArray[i].gcr_pNext, (intmax_t) pinArray[i].gcr_pPrev, (intmax_t) pinArray[i].gcr_pId);
     }
     pinArray=ch->gcr_rPins;
     TxPrintf("RIGHT PINS\n");
     for(i=0; i<=ch->gcr_width; i++)
     {
-	TxPrintf("Location [%d]=%d:  x=%d, y=%d, pNext=%d, pPrev=%d, id=%d\n",
-	i, &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
-	pinArray[i].gcr_pNext, pinArray[i].gcr_pPrev, pinArray[i].gcr_pId);
+	TxPrintf("Location [%d]=%ld:  x=%d, y=%d, pNext=%ld, pPrev=%ld, id=%ld\n",
+	i, (intmax_t) &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
+	(intmax_t) pinArray[i].gcr_pNext, (intmax_t) pinArray[i].gcr_pPrev, (intmax_t) pinArray[i].gcr_pId);
     }
     pinArray=ch->gcr_bPins;
     TxPrintf("BOTTOM PINS\n");
     for(i=0; i<=ch->gcr_length; i++)
     {
-	TxPrintf("Location [%d]=%d:  x=%d, y=%d, pNext=%d, pPrev=%d, id=%d\n",
-	i, &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
-	pinArray[i].gcr_pNext, pinArray[i].gcr_pPrev, pinArray[i].gcr_pId);
+	TxPrintf("Location [%d]=%ld:  x=%d, y=%d, pNext=%ld, pPrev=%ld, id=%ld\n",
+	i, (intmax_t) &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
+	(intmax_t) pinArray[i].gcr_pNext, (intmax_t) pinArray[i].gcr_pPrev, (intmax_t) pinArray[i].gcr_pId);
     }
     pinArray=ch->gcr_tPins;
     TxPrintf("TOP PINS\n");
     for(i=0; i<=ch->gcr_length; i++)
     {
-	TxPrintf("Location [%d]=%d:  x=%d, y=%d, pNext=%d, pPrev=%d, id=%d\n",
-	i, &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
-	pinArray[i].gcr_pNext, pinArray[i].gcr_pPrev, pinArray[i].gcr_pId);
+	TxPrintf("Location [%d]=%ld:  x=%d, y=%d, pNext=%ld, pPrev=%ld, id=%ld\n",
+	i, (intmax_t) &pinArray[i], pinArray[i].gcr_x, pinArray[i].gcr_y,
+	(intmax_t) pinArray[i].gcr_pNext, (intmax_t) pinArray[i].gcr_pPrev, (intmax_t) pinArray[i].gcr_pId);
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -504,14 +507,14 @@ gcrDumpPinList(pin, dir)
 {
     if (pin)
     {
-	TxPrintf("Location (%d, %d)=%x:  pNext=%d, pPrev=%d, id=%d\n",
-		pin->gcr_x, pin->gcr_y, pin,
-		pin->gcr_pNext, pin->gcr_pPrev, pin->gcr_pId);
+	TxPrintf("Location (%d, %d)=%lx:  pNext=%ld, pPrev=%ld, id=%ld\n",
+		pin->gcr_x, pin->gcr_y, (intmax_t) pin,
+		(intmax_t) pin->gcr_pNext, (intmax_t) pin->gcr_pPrev, (intmax_t) pin->gcr_pId);
 	if (dir) gcrDumpPinList(pin->gcr_pNext, dir);
 	else gcrDumpPinList(pin->gcr_pPrev, dir);
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -545,7 +548,7 @@ gcrDumpCol(col, size)
 	    col[i].gcr_h, col[i].gcr_v,
 	    col[i].gcr_wanted, col[i].gcr_flags);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -770,7 +773,7 @@ void  gcrPrintCol(ch, i, showResult)
     }
     TxPrintf(":\n");
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -850,7 +853,7 @@ gcrStats(ch)
     TxPrintf("Hwire  :  %d\n", hWire);
     TxPrintf("Vwire  :  %d\n", vWire);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -905,7 +908,7 @@ gcrCheckCol(ch, c, where)
 	       niceabort();
 	}
 	if(col[i].gcr_h!=(GCRNet *) NULL)
-	
+
 	/* Look upward from the track for the next higher track assigned to
 	 * the net, if any.  Just take the first one, breaking afterwards.
 	 */
@@ -944,7 +947,7 @@ gcrCheckCol(ch, c, where)
 	}
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -975,8 +978,12 @@ gcrShowMap(ch)
     while (1)
     {
 	TxPrintf("Field selector (0 terminates): ");
-	if(!scanf("%d", &field))	/*typed something funny*/
+	if(scanf("%d", &field) != 1)	/*typed something funny or EOF*/
 	{
+	    if (feof(stdin)) {
+	        TxPrintf("End of input detected. Terminating.\n");
+	        return;
+	    }
 	    TxPrintf("Bad input.  Legal responses are\n");
 	    TxPrintf("   GCRBLKM     1\n");
 	    TxPrintf("   GCRBLKP     2\n");
