@@ -143,7 +143,7 @@ grx11SetWMandC (mask, c)
     static int oldM = -1;
 
     c = grPixels[c];
-    if(grDisplay.depth <= 8) {
+    if (grDisplay.depth <= 8) {
       mask = grPlanes[mask];
       if (mask == -65) mask = AllPlanes;
     }
@@ -413,7 +413,7 @@ GrX11Init(dispType)
     grtemplate.screen = grXscrn;
     grtemplate.depth = 0;
     grvisual_get = XGetVisualInfo(grXdpy, VisualScreenMask, &grtemplate, &gritems);
-    if(grvisual_get == NULL)
+    if (grvisual_get == NULL)
     {
 	TxPrintf("Could not obtain Visual Info from Server %s. "
 		"Will attempt default.\n", getenv("DISPLAY"));
@@ -835,6 +835,8 @@ grX11Stdin()
 		    entry = HashLookOnly(&grX11WindowTable,grCurrent.window);
 	            w = (entry)?(MagWindow *)HashGetValue(entry):0;
 	            grCurrent.mw=w;
+	            if (!w)
+	                break;
 
 		    screenRect.r_xbot = ExposeEvent->x;
             	    screenRect.r_xtop = ExposeEvent->x+ExposeEvent->width;
@@ -888,6 +890,8 @@ grX11Stdin()
 
 		entry = HashLookOnly(&grX11WindowTable, VisEvent->window);
 		w = (entry)?(MagWindow *)HashGetValue(entry):0;
+		if (!w)
+		    break;
 
 		switch(VisEvent->state)
 		{
@@ -923,7 +927,7 @@ grX11Stdin()
    exception. Why X11 is generating an event for a non-existent
    window is another question... ***mdg***                             */
 
-                    if(w == 0) {printf("CreateNotify: w = %d.\n", w); break;}
+                    if (w == 0) {printf("CreateNotify: w = %d.\n", w); break;}
 		    SigDisableInterrupts();
 	    	    WindView(w);
 		    SigEnableInterrupts();
@@ -1179,13 +1183,13 @@ GrX11Create(w, name)
     grAttributes.border_pixel = BlackPixel(grXdpy,grXscrn);
     grAttributes.colormap = grXcmap;
     grDepth = grDisplay.depth;
-    if(grClass == 3) grDepth = 8;  /* Needed since grDisplay.depth is reset
+    if (grClass == 3) grDepth = 8;  /* Needed since grDisplay.depth is reset
 				     to 7 if Pseudocolor      */
 #ifdef HIRESDB
     TxPrintf("x %d y %d width %d height %d depth %d class %d mask %d\n",
       x,y,width,height, grDepth, grClass, attribmask);
 #endif  /* HIRESDB */
-    if ( wind = XCreateWindow(grXdpy,  XDefaultRootWindow(grXdpy),
+    if (wind = XCreateWindow(grXdpy,  XDefaultRootWindow(grXdpy),
     		x, y, width, height, 0, grDepth, InputOutput, grVisual,
                 attribmask, &grAttributes))
     {
