@@ -8,24 +8,25 @@
  * the search strongly toward the destination rather than
  * propagating isotropically from the starting points.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/grouter/grouteMaze.c,v 1.2 2001/01/12 22:12:51 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/grouter/grouteMaze.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
+#include <stdint.h>
 #include "utils/magic.h"
 #include "utils/geometry.h"
 #include "utils/geofast.h"
@@ -65,7 +66,7 @@ void glMazePropNormal();
 void glMazeTile();
 bool glMazeCheckLoop();
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -162,7 +163,7 @@ glMazeFindPath(loc, bestCost)
 
     return lastPt;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -208,7 +209,7 @@ glMazePropFinal(inPt, loc)
     HeapAddInt(&glMazeHeap, cost, (char *) outPt);
     glCrossingsAdded++;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -281,7 +282,7 @@ glMazePropRiver(inPt)
     glCrossingsAdded++;
 
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -335,7 +336,7 @@ glMazePropNormal(inPt)
 	if (NOTBLOCKEDH(tp))
 	    glMazeTile(inPt, tp, GEO_EAST);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -446,7 +447,7 @@ glMazeTile(inPt, tile, dir)
 	    break;
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -511,7 +512,7 @@ glMazeTileFunc(inPt, tp, pin)
 
     return 1;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -539,7 +540,7 @@ glMazeCheckLoop(path, tp)
 
     return FALSE;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -581,6 +582,7 @@ glMazeResetCost(headPage, headFree)
     }
 }
 
+void
 glPathPrint(path)
     GlPoint *path;
 {
@@ -594,10 +596,10 @@ glPathPrint(path)
 	pin = rp->gl_pin;
 	ch = pin->gcr_ch;
 	tp = rp->gl_tile;
-	TxPrintf("(%d,%d) cost=%d pcost=%d pId=%d/%d\n",
+	TxPrintf("(%d,%d) cost=%d pcost=%d pId=%ld/%d\n",
 		pin->gcr_point.p_x, pin->gcr_point.p_y,
 		rp->gl_cost, pin->gcr_cost,
-		pin->gcr_pId, pin->gcr_pSeg);
+		(intmax_t) pin->gcr_pId, pin->gcr_pSeg);
 	TxPrintf("\tchan=(%d,%d,%d,%d)/%d\n",
 		ch->gcr_area.r_xbot, ch->gcr_area.r_ybot,
 		ch->gcr_area.r_xtop, ch->gcr_area.r_ytop,
