@@ -4,21 +4,21 @@
  * Plowing.
  * Debugging and testing.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowTest.c,v 1.3 2001/06/15 15:33:40 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/plow/PlowTest.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -70,7 +70,7 @@ Point plowWhenTopPoint, plowWhenBotPoint;
 
 /* Imports */
 extern CellDef *plowSpareDef;
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -307,8 +307,8 @@ PlowTest(w, cmd)
 	    tp = TiSrPointNoHint(plane, &editArea.r_ll);
 	    if (cmd->tx_argc == 3) trail = atoi(cmd->tx_argv[2]);
 	    else trail = editArea.r_xtop;
-	    TxPrintf("Trailing coordinate of tile 0x%x updated from %d to %d\n",
-			tp, TRAILING(tp), trail);
+	    TxPrintf("Trailing coordinate of tile %p updated from %d to %d\n",
+			(void *)tp, TRAILING(tp), trail);
 	    plowSetTrailing(tp, trail);
 	    break;
 	case PC_MOVE:
@@ -328,13 +328,13 @@ PlowTest(w, cmd)
 		return;
 	    }
 	    TiToRect(tp, &area2);
-	    TxPrintf("Splitting tile 0x%x at y=%d yielding 0x%x\n",
-			tp, editArea.r_ybot, plowSplitY(tp, editArea.r_ybot));
+	    TxPrintf("Splitting tile %p at y=%d yielding %p\n",
+			(void *)tp, editArea.r_ybot, (void *)plowSplitY(tp, editArea.r_ybot));
 	    DBWAreaChanged(def, &area2, DBW_ALLWINDOWS, &DBAllButSpaceBits);
 	    break;
 	case PC_MERGEDOWN:
 	    tp = TiSrPointNoHint(plane, &editArea.r_ll);
-	    TxPrintf("Merging tile 0x%x below\n", tp);
+	    TxPrintf("Merging tile %p below\n", tp);
 	    TiToRect(tp, &editArea);
 	    TiToRect(RT(tp), &area2);
 	    (void) GeoInclude(&area2, &editArea);
@@ -343,7 +343,7 @@ PlowTest(w, cmd)
 	    break;
 	case PC_MERGEUP:
 	    tp = TiSrPointNoHint(plane, &editArea.r_ll);
-	    TxPrintf("Merging tile 0x%x above\n", tp);
+	    TxPrintf("Merging tile %p above\n", tp);
 	    TiToRect(tp, &editArea);
 	    TiToRect(RT(tp), &area2);
 	    (void) GeoInclude(&area2, &editArea);
@@ -352,7 +352,7 @@ PlowTest(w, cmd)
 	    break;
 	case PC_PRINT:
 	    tp = TiSrPointNoHint(plane, &editArea.r_ll);
-	    TxPrintf("Tile 0x%x  LEFT=%d RIGHT=%d BOTTOM=%d TOP=%d\n",
+	    TxPrintf("Tile %p  LEFT=%d RIGHT=%d BOTTOM=%d TOP=%d\n",
 		tp, LEFT(tp), RIGHT(tp), BOTTOM(tp), TOP(tp));
 	    TxPrintf("    TRAILING=%d LEADING=%d TYPE=%s\n",
 		TRAILING(tp), LEADING(tp), DBTypeLongName(TiGetTypeExact(tp)));
@@ -389,7 +389,7 @@ PlowTest(w, cmd)
 	    break;
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -431,7 +431,7 @@ plowGetCommand(cmd)
 
     return (plowCmds[plowIndex].p_cmd);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -472,7 +472,7 @@ plowDebugInit()
     for (n = 0; debug[n].di_name; n++)
 	*(debug[n].di_id) = DebugAddFlag(plowDebugID, debug[n].di_name);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -508,7 +508,7 @@ plowShowShadow(edge, def)
     edgeArea.r_ytop = edge->e_ytop * scaleFactor;
     DBWFeedbackAdd(&edgeArea, mesg, def, scaleFactor, STYLE_SOLIDHIGHLIGHTS);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -550,10 +550,10 @@ plowTestJog(def, area)
     plowDummyUse->cu_def = def;
     scx.scx_use = plowDummyUse;
     scx.scx_trans = GeoIdentityTransform;
-    scx.scx_area.r_xbot = area->r_xbot - TechHalo;
-    scx.scx_area.r_ybot = area->r_ybot - TechHalo;
-    scx.scx_area.r_xtop = area->r_xtop + TechHalo;
-    scx.scx_area.r_ytop = area->r_ytop + TechHalo;
+    scx.scx_area.r_xbot = area->r_xbot - DRCTechHalo;
+    scx.scx_area.r_ybot = area->r_ybot - DRCTechHalo;
+    scx.scx_area.r_xtop = area->r_xtop + DRCTechHalo;
+    scx.scx_area.r_ytop = area->r_ytop + DRCTechHalo;
     (void) DBCellCopyPaint(&scx, &DBAllButSpaceAndDRCBits, 0, plowYankUse);
     DBReComputeBbox(plowYankDef);
     DBWAreaChanged(plowYankDef,&TiPlaneRect,DBW_ALLWINDOWS,&DBAllButSpaceBits);
@@ -582,7 +582,7 @@ plowTestJog(def, area)
     DBWAreaChanged(def, area, DBW_ALLWINDOWS, &DBAllButSpaceBits);
     DRCCheckThis(def, TT_CHECKPAINT, area);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -654,10 +654,10 @@ plowDebugEdge(edge, rtePtr, mesg)
     WindUpdate();
 
     plowDebugMore();
-    DBWFeedbackClear();
+    DBWFeedbackClear(NULL);
     WindUpdate();
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -693,7 +693,7 @@ again:
 	goto again;
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -789,7 +789,7 @@ plowShowOutline(outline, clipArea)
 
     return (0);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
